OiRA

Help

1. Paruošimas
2. Įtraukti
3. Nustatymas + Vertinimas
4. Veiksmų planas
5. Ataskaita
6. Būsena 0%

# Ataskaitų ruošimas

Kadangi jau baigėte visus jūsų organizacijos rizikų vertinimo procesus ir sukūrėte prevencinių veiksmų planą, galite sukurti ataskaitą su visais rezultatais. Taip pat galite (jei norite) įkelti papildomus komentarus, kuriuos norite įtraukti į žemiau esantį ataskaitos laukelį.

Išsaugoti ir tęsti

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More